@@ -82,6 +82,7 @@ static guint backend_signals[LAST_SIGNAL] = { 0, };
 static void
 clutter_backend_dispose (GObject *gobject)
 {
+  ClutterBackend *backend = CLUTTER_BACKEND (gobject);
   ClutterMainContext *clutter_context;
 
   clutter_context = _clutter_context_get_default ();
@@ -95,18 +96,11 @@ clutter_backend_dispose (GObject *gobject)
       clutter_context->events_queue = NULL;
     }
 
-  G_OBJECT_CLASS (clutter_backend_parent_class)->dispose (gobject);
-}
-
-static void
-clutter_backend_finalize (GObject *gobject)
-{
-  ClutterBackend *backend = CLUTTER_BACKEND (gobject);
-
   g_free (backend->priv->font_name);
+
   clutter_backend_set_font_options (backend, NULL);
 
-  G_OBJECT_CLASS (clutter_backend_parent_class)->finalize (gobject);
+  G_OBJECT_CLASS (clutter_backend_parent_class)->dispose (gobject);
 }
 
 static gfloat
@@ -202,7 +196,6 @@ clutter_backend_class_init (ClutterBackendClass *klass)
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
   gobject_class->dispose = clutter_backend_dispose;
-  gobject_class->finalize = clutter_backend_finalize;
 
   g_type_class_add_private (gobject_class, sizeof (ClutterBackendPrivate));
 
@@ -432,7 +425,7 @@ _clutter_backend_ensure_context (ClutterBackend *backend,
       if (current_context_stage)
         {
           CLUTTER_SET_PRIVATE_FLAGS (current_context_stage,
-                                     CLUTTER_SYNC_MATRICES);
+                                     CLUTTER_ACTOR_SYNC_MATRICES);
         }
     }
   else
@@ -518,36 +511,6 @@ _clutter_backend_get_units_per_em (ClutterBackend       *backend,
   return priv->units_per_em;
 }
 
-void
-_clutter_backend_copy_event_data (ClutterBackend *backend,
-                                  ClutterEvent   *src,
-                                  ClutterEvent   *dest)
-{
-  ClutterBackendClass *klass;
-
-  g_return_if_fail (CLUTTER_IS_BACKEND (backend));
-  g_return_if_fail (src != NULL);
-  g_return_if_fail (dest != NULL);
-
-  klass = CLUTTER_BACKEND_GET_CLASS (backend);
-  if (klass->copy_event_data != NULL)
-    klass->copy_event_data (backend, src, dest);
-}
-
-void
-_clutter_backend_free_event_data (ClutterBackend *backend,
-                                  ClutterEvent   *event)
-{
-  ClutterBackendClass *klass;
-
-  g_return_if_fail (CLUTTER_IS_BACKEND (backend));
-  g_return_if_fail (event != NULL);
-
-  klass = CLUTTER_BACKEND_GET_CLASS (backend);
-  if (klass->free_event_data != NULL)
-    klass->free_event_data (backend, event);
-}
-
 /**
  * clutter_get_default_backend:
  *
