@@ -82,7 +82,6 @@ struct _ClutterDragActionPrivate
   gfloat press_x;
   gfloat press_y;
   ClutterModifierType press_state;
-  gint press_button;
 
   gfloat last_motion_x;
   gfloat last_motion_y;
@@ -90,8 +89,9 @@ struct _ClutterDragActionPrivate
   gfloat transformed_press_x;
   gfloat transformed_press_y;
 
-  guint emit_delayed_press : 1;
-  guint in_drag            : 1;
+  guint emit_delayed_press    : 1;
+  guint in_drag               : 1;
+  guint motion_events_enabled : 1;
 };
 
 enum
@@ -128,10 +128,12 @@ emit_drag_begin (ClutterDragAction *action,
 {
   ClutterDragActionPrivate *priv = action->priv;
 
+  priv->motion_events_enabled = clutter_get_motion_events_enabled ();
+  clutter_set_motion_events_enabled (FALSE);
+
   g_signal_emit (action, drag_signals[DRAG_BEGIN], 0,
                  actor,
                  priv->press_x, priv->press_y,
-                 priv->press_button,
                  priv->press_state);
 }
 
@@ -212,7 +214,6 @@ emit_drag_end (ClutterDragAction *action,
     g_signal_emit (action, drag_signals[DRAG_END], 0,
                    actor,
                    priv->last_motion_x, priv->last_motion_y,
-                   priv->press_button,
                    clutter_event_get_state (event));
 
   /* disconnect the capture */
@@ -222,6 +223,8 @@ emit_drag_end (ClutterDragAction *action,
       priv->capture_id = 0;
     }
 
+  clutter_set_motion_events_enabled (priv->motion_events_enabled);
+
   priv->in_drag = FALSE;
 }
 
@@ -277,11 +280,13 @@ on_button_press (ClutterActor      *actor,
   if (!clutter_actor_meta_get_enabled (CLUTTER_ACTOR_META (action)))
     return FALSE;
 
+  if (clutter_event_get_button (event) != 1)
+    return FALSE;
+
   if (priv->stage == NULL)
     priv->stage = clutter_actor_get_stage (actor);
 
   clutter_event_get_coords (event, &priv->press_x, &priv->press_y);
-  priv->press_button = clutter_event_get_button (event);
   priv->press_state = clutter_event_get_state (event);
 
   priv->last_motion_x = priv->press_x;
@@ -512,7 +517,6 @@ clutter_drag_action_class_init (ClutterDragActionClass *klass)
    * @actor: the #ClutterActor attached to the action
    * @event_x: the X coordinate (in stage space) of the press event
    * @event_y: the Y coordinate (in stage space) of the press event
-   * @button: the button of the press event
    * @modifiers: the modifiers of the press event
    *
    * The ::drag-begin signal is emitted when the #ClutterDragAction
@@ -529,12 +533,11 @@ clutter_drag_action_class_init (ClutterDragActionClass *klass)
                   G_SIGNAL_RUN_LAST,
                   G_STRUCT_OFFSET (ClutterDragActionClass, drag_begin),
                   NULL, NULL,
-                  clutter_marshal_VOID__OBJECT_FLOAT_FLOAT_INT_FLAGS,
-                  G_TYPE_NONE, 5,
+                  _clutter_marshal_VOID__OBJECT_FLOAT_FLOAT_FLAGS,
+                  G_TYPE_NONE, 4,
                   CLUTTER_TYPE_ACTOR,
                   G_TYPE_FLOAT,
                   G_TYPE_FLOAT,
-                  G_TYPE_INT,
                   CLUTTER_TYPE_MODIFIER_TYPE);
 
   /**
@@ -572,7 +575,7 @@ clutter_drag_action_class_init (ClutterDragActionClass *klass)
                   G_SIGNAL_RUN_LAST,
                   G_STRUCT_OFFSET (ClutterDragActionClass, drag_motion),
                   NULL, NULL,
-                  clutter_marshal_VOID__OBJECT_FLOAT_FLOAT,
+                  _clutter_marshal_VOID__OBJECT_FLOAT_FLOAT,
                   G_TYPE_NONE, 3,
                   CLUTTER_TYPE_ACTOR,
                   G_TYPE_FLOAT,
@@ -584,7 +587,6 @@ clutter_drag_action_class_init (ClutterDragActionClass *klass)
    * @actor: the #ClutterActor attached to the action
    * @event_x: the X coordinate (in stage space) of the release event
    * @event_y: the Y coordinate (in stage space) of the release event
-   * @button: the button of the release event
    * @modifiers: the modifiers of the release event
    *
    * The ::drag-end signal is emitted at the end of the dragging,
@@ -601,12 +603,11 @@ clutter_drag_action_class_init (ClutterDragActionClass *klass)
                   G_SIGNAL_RUN_LAST,
                   G_STRUCT_OFFSET (ClutterDragActionClass, drag_end),
                   NULL, NULL,
-                  clutter_marshal_VOID__OBJECT_FLOAT_FLOAT_INT_FLAGS,
-                  G_TYPE_NONE, 5,
+                  _clutter_marshal_VOID__OBJECT_FLOAT_FLOAT_FLAGS,
+                  G_TYPE_NONE, 4,
                   CLUTTER_TYPE_ACTOR,
                   G_TYPE_FLOAT,
                   G_TYPE_FLOAT,
-                  G_TYPE_INT,
                   CLUTTER_TYPE_MODIFIER_TYPE);
 }
 
