@@ -53,9 +53,8 @@
 #include "config.h"
 #endif
 
-#include "clutter-stage.h"
-
 #include "clutter-backend.h"
+#include "clutter-stage.h"
 #include "clutter-main.h"
 #include "clutter-color.h"
 #include "clutter-util.h"
@@ -79,25 +78,6 @@ G_DEFINE_TYPE (ClutterStage, clutter_stage, CLUTTER_TYPE_GROUP);
 #define CLUTTER_STAGE_GET_PRIVATE(obj) \
 (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CLUTTER_TYPE_STAGE, ClutterStagePrivate))
 
-/* <private>
- * ClutterStageHint:
- * @CLUTTER_STAGE_NONE: No hint set
- * @CLUTTER_STAGE_NO_CLEAR_ON_PAINT: When this hint is set, the stage
- *   should not clear the viewport; this flag is useful when painting
- *   fully opaque actors covering the whole visible area of the stage,
- *   i.e. when no blending with the stage color happens over the whole
- *   stage viewport
- *
- * A series of hints that enable or disable behaviours on the stage
- */
-typedef enum { /*< prefix=CLUTTER_STAGE >*/
-  CLUTTER_STAGE_HINT_NONE = 0,
-
-  CLUTTER_STAGE_NO_CLEAR_ON_PAINT = 1 << 0
-} ClutterStageHint;
-
-#define STAGE_NO_CLEAR_ON_PAINT(s)      ((((ClutterStage *) (s))->priv->stage_hints & CLUTTER_STAGE_NO_CLEAR_ON_PAINT) != 0)
-
 struct _ClutterStagePrivate
 {
   /* the stage implementation */
@@ -112,8 +92,6 @@ struct _ClutterStagePrivate
 
   GQueue             *event_queue;
 
-  ClutterStageHint    stage_hints;
-
   guint redraw_pending         : 1;
   guint is_fullscreen          : 1;
   guint is_cursor_visible      : 1;
@@ -134,12 +112,11 @@ enum
   PROP_CURSOR_VISIBLE,
   PROP_PERSPECTIVE,
   PROP_TITLE,
-  PROP_USER_RESIZABLE,
+  PROP_USER_RESIZE,
   PROP_USE_FOG,
   PROP_FOG,
   PROP_USE_ALPHA,
-  PROP_KEY_FOCUS,
-  PROP_NO_CLEAR_HINT
+  PROP_KEY_FOCUS
 };
 
 enum
@@ -297,7 +274,6 @@ static void
 clutter_stage_paint (ClutterActor *self)
 {
   ClutterStagePrivate *priv = CLUTTER_STAGE (self)->priv;
-  CoglBufferBit clear_flags;
   CoglColor stage_color;
   guint8 real_alpha;
   CLUTTER_STATIC_TIMER (stage_clear_timer,
@@ -324,14 +300,10 @@ clutter_stage_paint (ClutterActor *self)
                                            : 255);
   cogl_color_premultiply (&stage_color);
 
-  clear_flags = COGL_BUFFER_BIT_DEPTH;
-  if (!STAGE_NO_CLEAR_ON_PAINT (self))
-    clear_flags |= COGL_BUFFER_BIT_COLOR;
-
   CLUTTER_TIMER_START (_clutter_uprof_context, stage_clear_timer);
-
-  cogl_clear (&stage_color, clear_flags);
-
+  cogl_clear (&stage_color,
+	      COGL_BUFFER_BIT_COLOR |
+	      COGL_BUFFER_BIT_DEPTH);
   CLUTTER_TIMER_STOP (_clutter_uprof_context, stage_clear_timer);
 
   if (priv->use_fog)
@@ -376,7 +348,7 @@ clutter_stage_realize (ClutterActor *self)
    * first paint (which will likely occur before the ConfigureNotify
    * is received)
    */
-  CLUTTER_SET_PRIVATE_FLAGS (self, CLUTTER_SYNC_MATRICES);
+  CLUTTER_SET_PRIVATE_FLAGS (self, CLUTTER_ACTOR_SYNC_MATRICES);
 
   g_assert (priv->impl != NULL);
   is_realized = _clutter_stage_window_realize (priv->impl);
@@ -386,13 +358,6 @@ clutter_stage_realize (ClutterActor *self)
    */
   if (is_realized)
     {
-	//MAEMO5 PR-1.3 FIX.//
-	// reverting these rows back to git: 568c29ba491e4a6b3bef426be528d7246110011c
-	CLUTTER_ACTOR_SET_FLAGS (self, CLUTTER_ACTOR_REALIZED);
-	clutter_stage_ensure_current (CLUTTER_STAGE (self));
-	return;
-	//MAEMO5 PR-1.3 FIX.//
-
       ClutterBackend *backend = clutter_get_default_backend ();
       GError *error = NULL;
 
@@ -779,9 +744,6 @@ _clutter_stage_has_full_redraw_queued (ClutterStage *stage)
 {
   ClutterStageWindow *stage_window = _clutter_stage_get_window (stage);
 
-  if (CLUTTER_ACTOR_IN_DESTRUCTION (stage) || stage_window == NULL)
-    return FALSE;
-
   if (stage->priv->redraw_pending &&
       !_clutter_stage_window_has_redraw_clips (stage_window))
     return TRUE;
@@ -835,7 +797,7 @@ clutter_stage_set_property (GObject      *object,
       clutter_stage_set_title (stage, g_value_get_string (value));
       break;
 
-    case PROP_USER_RESIZABLE:
+    case PROP_USER_RESIZE:
       clutter_stage_set_user_resizable (stage, g_value_get_boolean (value));
       break;
 
@@ -855,10 +817,6 @@ clutter_stage_set_property (GObject      *object,
       clutter_stage_set_key_focus (stage, g_value_get_object (value));
       break;
 
-    case PROP_NO_CLEAR_HINT:
-      clutter_stage_set_no_clear_hint (stage, g_value_get_boolean (value));
-      break;
-
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -899,7 +857,7 @@ clutter_stage_get_property (GObject    *gobject,
       g_value_set_string (value, priv->title);
       break;
 
-    case PROP_USER_RESIZABLE:
+    case PROP_USER_RESIZE:
       g_value_set_boolean (value, priv->is_user_resizable);
       break;
 
@@ -919,15 +877,6 @@ clutter_stage_get_property (GObject    *gobject,
       g_value_set_object (value, priv->key_focused_actor);
       break;
 
-    case PROP_NO_CLEAR_HINT:
-      {
-        gboolean hint =
-          (priv->stage_hints & CLUTTER_STAGE_NO_CLEAR_ON_PAINT) != 0;
-
-        g_value_set_boolean (value, hint);
-      }
-      break;
-
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (gobject, prop_id, pspec);
       break;
@@ -1025,8 +974,8 @@ clutter_stage_class_init (ClutterStageClass *klass)
    * Since: 1.0
    */
   pspec = g_param_spec_boolean ("fullscreen-set",
-                                P_("Fullscreen Set"),
-                                P_("Whether the main stage is fullscreen"),
+                                "Fullscreen Set",
+                                "Whether the main stage is fullscreen",
                                 FALSE,
                                 CLUTTER_PARAM_READABLE);
   g_object_class_install_property (gobject_class,
@@ -1042,8 +991,9 @@ clutter_stage_class_init (ClutterStageClass *klass)
    * and it might be deprecated at any later date.</para></warning>
    */
   pspec = g_param_spec_boolean ("offscreen",
-                                P_("Offscreen"),
-                                P_("Whether the main stage should be rendered offscreen"),
+                                "Offscreen",
+                                "Whether the main stage should be "
+                                "rendered offscreen",
                                 FALSE,
                                 CLUTTER_PARAM_READWRITE);
   g_object_class_install_property (gobject_class,
@@ -1055,8 +1005,9 @@ clutter_stage_class_init (ClutterStageClass *klass)
    * Whether the mouse pointer should be visible
    */
   pspec = g_param_spec_boolean ("cursor-visible",
-                                P_("Cursor Visible"),
-                                P_("Whether the mouse pointer is visible on the main stage"),
+                                "Cursor Visible",
+                                "Whether the mouse pointer is visible "
+                                "on the main stage",
                                 TRUE,
                                 CLUTTER_PARAM_READWRITE);
   g_object_class_install_property (gobject_class,
@@ -1070,12 +1021,13 @@ clutter_stage_class_init (ClutterStageClass *klass)
    * Since: 0.4
    */
   pspec = g_param_spec_boolean ("user-resizable",
-                                P_("User Resizable"),
-                                P_("Whether the stage is able to be resized via user interaction"),
+                                "User Resizable",
+                                "Whether the stage is able to be resized "
+                                "via user interaction",
                                 FALSE,
                                 CLUTTER_PARAM_READWRITE);
   g_object_class_install_property (gobject_class,
-                                   PROP_USER_RESIZABLE,
+                                   PROP_USER_RESIZE,
                                    pspec);
   /**
    * ClutterStage:color:
@@ -1083,8 +1035,8 @@ clutter_stage_class_init (ClutterStageClass *klass)
    * The color of the main stage.
    */
   pspec = clutter_param_spec_color ("color",
-                                    P_("Color"),
-                                    P_("The color of the stage"),
+                                    "Color",
+                                    "The color of the stage",
                                     &default_stage_color,
                                     CLUTTER_PARAM_READWRITE);
   g_object_class_install_property (gobject_class, PROP_COLOR, pspec);
@@ -1098,8 +1050,8 @@ clutter_stage_class_init (ClutterStageClass *klass)
    * Since: 0.8.2
    */
   pspec = g_param_spec_boxed ("perspective",
-                              P_("Perspective"),
-                              P_("Perspective projection parameters"),
+                              "Perspective",
+                              "Perspective projection parameters",
                               CLUTTER_TYPE_PERSPECTIVE,
                               CLUTTER_PARAM_READWRITE);
   g_object_class_install_property (gobject_class,
@@ -1114,8 +1066,8 @@ clutter_stage_class_init (ClutterStageClass *klass)
    * Since: 0.4
    */
   pspec = g_param_spec_string ("title",
-                               P_("Title"),
-                               P_("Stage Title"),
+                               "Title",
+                               "Stage Title",
                                NULL,
                                CLUTTER_PARAM_READWRITE);
   g_object_class_install_property (gobject_class, PROP_TITLE, pspec);
@@ -1130,8 +1082,8 @@ clutter_stage_class_init (ClutterStageClass *klass)
    * Since: 0.6
    */
   pspec = g_param_spec_boolean ("use-fog",
-                                P_("Use Fog"),
-                                P_("Whether to enable depth cueing"),
+                                "Use Fog",
+                                "Whether to enable depth cueing",
                                 FALSE,
                                 CLUTTER_PARAM_READWRITE);
   g_object_class_install_property (gobject_class, PROP_USE_FOG, pspec);
@@ -1145,8 +1097,8 @@ clutter_stage_class_init (ClutterStageClass *klass)
    * Since: 1.0
    */
   pspec = g_param_spec_boxed ("fog",
-                              P_("Fog"),
-                              P_("Settings for the depth cueing"),
+                              "Fog",
+                              "Settings for the depth cueing",
                               CLUTTER_TYPE_FOG,
                               CLUTTER_PARAM_READWRITE);
   g_object_class_install_property (gobject_class, PROP_FOG, pspec);
@@ -1162,8 +1114,9 @@ clutter_stage_class_init (ClutterStageClass *klass)
    * Since: 1.2
    */
   pspec = g_param_spec_boolean ("use-alpha",
-                                P_("Use Alpha"),
-                                P_("Whether to honour the alpha component of the stage color"),
+                                "Use Alpha",
+                                "Whether to honour the alpha component of "
+                                "the stage color",
                                 FALSE,
                                 CLUTTER_PARAM_READWRITE);
   g_object_class_install_property (gobject_class, PROP_USE_ALPHA, pspec);
@@ -1179,29 +1132,12 @@ clutter_stage_class_init (ClutterStageClass *klass)
    * Since: 1.2
    */
   pspec = g_param_spec_object ("key-focus",
-                               P_("Key Focus"),
-                               P_("The currently key focused actor"),
+                               "Key Focus",
+                               "The currently key focused actor",
                                CLUTTER_TYPE_ACTOR,
                                CLUTTER_PARAM_READWRITE);
   g_object_class_install_property (gobject_class, PROP_KEY_FOCUS, pspec);
 
-  /**
-   * ClutterStage:no-clear-hint:
-   *
-   * Whether or not the #ClutterStage should clear its contents
-   * before each paint cycle.
-   *
-   * See clutter_stage_set_no_clear_hint() for further information.
-   *
-   * Since: 1.4
-   */
-  pspec = g_param_spec_boolean ("no-clear-hint",
-                                P_("No Clear Hint"),
-                                P_("Whether the stage should clear its contents"),
-                                FALSE,
-                                CLUTTER_PARAM_READWRITE);
-  g_object_class_install_property (gobject_class, PROP_NO_CLEAR_HINT, pspec);
-
   /**
    * ClutterStage::fullscreen
    * @stage: the stage which was fullscreened
@@ -1211,7 +1147,7 @@ clutter_stage_class_init (ClutterStageClass *klass)
    * Since: 0.6
    */
   stage_signals[FULLSCREEN] =
-    g_signal_new (I_("fullscreen"),
+    g_signal_new ("fullscreen",
 		  G_TYPE_FROM_CLASS (gobject_class),
 		  G_SIGNAL_RUN_FIRST,
 		  G_STRUCT_OFFSET (ClutterStageClass, fullscreen),
@@ -1228,7 +1164,7 @@ clutter_stage_class_init (ClutterStageClass *klass)
    * Since: 0.6
    */
   stage_signals[UNFULLSCREEN] =
-    g_signal_new (I_("unfullscreen"),
+    g_signal_new ("unfullscreen",
 		  G_TYPE_FROM_CLASS (gobject_class),
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (ClutterStageClass, unfullscreen),
@@ -1245,7 +1181,7 @@ clutter_stage_class_init (ClutterStageClass *klass)
    * Since: 0.6
    */
   stage_signals[ACTIVATE] =
-    g_signal_new (I_("activate"),
+    g_signal_new ("activate",
 		  G_TYPE_FROM_CLASS (gobject_class),
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (ClutterStageClass, activate),
@@ -1262,7 +1198,7 @@ clutter_stage_class_init (ClutterStageClass *klass)
    * Since: 0.6
    */
   stage_signals[DEACTIVATE] =
-    g_signal_new (I_("deactivate"),
+    g_signal_new ("deactivate",
 		  G_TYPE_FROM_CLASS (gobject_class),
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (ClutterStageClass, deactivate),
@@ -1322,7 +1258,7 @@ clutter_stage_init (ClutterStage *self)
   ClutterBackend *backend;
 
   /* a stage is a top-level object */
-  CLUTTER_SET_PRIVATE_FLAGS (self, CLUTTER_IS_TOPLEVEL);
+  CLUTTER_SET_PRIVATE_FLAGS (self, CLUTTER_ACTOR_IS_TOPLEVEL);
 
   self->priv = priv = CLUTTER_STAGE_GET_PRIVATE (self);
 
@@ -1475,7 +1411,7 @@ clutter_stage_set_perspective (ClutterStage       *stage,
   /* this will cause the viewport to be reset; see
    * clutter_maybe_setup_viewport() inside clutter-main.c
    */
-  CLUTTER_SET_PRIVATE_FLAGS (stage, CLUTTER_SYNC_MATRICES);
+  CLUTTER_SET_PRIVATE_FLAGS (stage, CLUTTER_ACTOR_SYNC_MATRICES);
 }
 
 /**
@@ -2287,7 +2223,7 @@ clutter_stage_ensure_viewport (ClutterStage *stage)
 {
   g_return_if_fail (CLUTTER_IS_STAGE (stage));
 
-  CLUTTER_SET_PRIVATE_FLAGS (stage, CLUTTER_SYNC_MATRICES);
+  CLUTTER_SET_PRIVATE_FLAGS (stage, CLUTTER_ACTOR_SYNC_MATRICES);
 
   clutter_actor_queue_redraw (CLUTTER_ACTOR (stage));
 }
@@ -2586,7 +2522,7 @@ _clutter_stage_get_pending_swaps (ClutterStage *stage)
 {
   ClutterStageWindow *stage_window;
 
-  if (CLUTTER_ACTOR_IN_DESTRUCTION (stage))
+  if (CLUTTER_PRIVATE_FLAGS (stage) & CLUTTER_ACTOR_IN_DESTRUCTION)
     return 0;
 
   stage_window = _clutter_stage_get_window (stage);
@@ -2595,69 +2531,3 @@ _clutter_stage_get_pending_swaps (ClutterStage *stage)
 
   return _clutter_stage_window_get_pending_swaps (stage_window);
 }
-
-/**
- * clutter_stage_set_no_clear_hint:
- * @stage: a #ClutterStage
- * @no_clear: %TRUE if the @stage should not clear itself on every
- *   repaint cycle
- *
- * Sets whether the @stage should clear itself at the beginning
- * of each paint cycle or not.
- *
- * Clearing the #ClutterStage can be a costly operation, especially
- * if the stage is always covered - for instance, in a full-screen
- * video player or in a game with a background texture.
- *
- * <note><para>This setting is a hint; Clutter might discard this
- * hint depending on its internal state.</para></note>
- *
- * <warning><para>If parts of the stage are visible and you disable
- * clearing you might end up with visual artifacts while painting the
- * contents of the stage.</para></warning>
- *
- * Since: 1.4
- */
-void
-clutter_stage_set_no_clear_hint (ClutterStage *stage,
-                                 gboolean      no_clear)
-{
-  ClutterStagePrivate *priv;
-  ClutterStageHint new_hints;
-
-  g_return_if_fail (CLUTTER_IS_STAGE (stage));
-
-  priv = stage->priv;
-  new_hints = priv->stage_hints;
-
-  if (no_clear)
-    new_hints |= CLUTTER_STAGE_NO_CLEAR_ON_PAINT;
-  else
-    new_hints &= ~CLUTTER_STAGE_NO_CLEAR_ON_PAINT;
-
-  if (priv->stage_hints == new_hints)
-    return;
-
-  priv->stage_hints = new_hints;
-
-  g_object_notify (G_OBJECT (stage), "no-clear-hint");
-}
-
-/**
- * clutter_stage_get_no_clear_hint:
- * @stage: a #ClutterStage
- *
- * Retrieves the hint set with clutter_stage_set_no_clear_hint()
- *
- * Return value: %TRUE if the stage should not clear itself on every paint
- *   cycle, and %FALSE otherwise
- *
- * Since: 1.4
- */
-gboolean
-clutter_stage_get_no_clear_hint (ClutterStage *stage)
-{
-  g_return_val_if_fail (CLUTTER_IS_STAGE (stage), FALSE);
-
-  return (stage->priv->stage_hints & CLUTTER_STAGE_NO_CLEAR_ON_PAINT) != 0;
-}
