@@ -3,7 +3,7 @@
  *
  * An object oriented GL/GLES Abstraction/Utility Layer
  *
- * Copyright (C) 2007,2008,2009 Intel Corporation.
+ * Copyright (C) 2007,2008,2009,2010 Intel Corporation.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -29,8 +29,11 @@
 
 G_BEGIN_DECLS
 
-#define CLUTTER_COGL_HAS_GL 1
+
+#define COGL_HAS_X11 1
+#define COGL_HAS_XLIB 1
 #define COGL_HAS_GL 1
+#define CLUTTER_COGL_HAS_GL 1
 
 G_END_DECLS
 
