@@ -100,11 +100,16 @@ cogl_debug_flags_get_type (void)
         { COGL_DEBUG_BATCHING, "COGL_DEBUG_BATCHING", "batching" },
         { COGL_DEBUG_DISABLE_SOFTWARE_TRANSFORM, "COGL_DEBUG_DISABLE_SOFTWARE_TRANSFORM", "disable-software-transform" },
         { COGL_DEBUG_MATRICES, "COGL_DEBUG_MATRICES", "matrices" },
-        { COGL_DEBUG_FORCE_SCANLINE_PATHS, "COGL_DEBUG_FORCE_SCANLINE_PATHS", "force-scanline-paths" },
         { COGL_DEBUG_ATLAS, "COGL_DEBUG_ATLAS", "atlas" },
         { COGL_DEBUG_DUMP_ATLAS_IMAGE, "COGL_DEBUG_DUMP_ATLAS_IMAGE", "dump-atlas-image" },
         { COGL_DEBUG_DISABLE_ATLAS, "COGL_DEBUG_DISABLE_ATLAS", "disable-atlas" },
         { COGL_DEBUG_OPENGL, "COGL_DEBUG_OPENGL", "opengl" },
+        { COGL_DEBUG_DISABLE_TEXTURING, "COGL_DEBUG_DISABLE_TEXTURING", "disable-texturing" },
+        { COGL_DEBUG_DISABLE_ARBFP, "COGL_DEBUG_DISABLE_ARBFP", "disable-arbfp" },
+        { COGL_DEBUG_DISABLE_GLSL, "COGL_DEBUG_DISABLE_GLSL", "disable-glsl" },
+        { COGL_DEBUG_SHOW_SOURCE, "COGL_DEBUG_SHOW_SOURCE", "show-source" },
+        { COGL_DEBUG_DISABLE_BLENDING, "COGL_DEBUG_DISABLE_BLENDING", "disable-blending" },
+        { COGL_DEBUG_TEXTURE_PIXMAP, "COGL_DEBUG_TEXTURE_PIXMAP", "texture-pixmap" },
         { 0, NULL, NULL }
       };
       GType g_enum_type_id;
@@ -148,6 +153,29 @@ cogl_material_filter_get_type (void)
   return g_enum_type_id__volatile;
 }
 GType
+cogl_material_wrap_mode_get_type (void)
+{
+  static volatile gsize g_enum_type_id__volatile = 0;
+
+  if (g_once_init_enter (&g_enum_type_id__volatile))
+    {
+      static const GEnumValue values[] = {
+        { COGL_MATERIAL_WRAP_MODE_REPEAT, "COGL_MATERIAL_WRAP_MODE_REPEAT", "repeat" },
+        { COGL_MATERIAL_WRAP_MODE_CLAMP_TO_EDGE, "COGL_MATERIAL_WRAP_MODE_CLAMP_TO_EDGE", "clamp-to-edge" },
+        { COGL_MATERIAL_WRAP_MODE_AUTOMATIC, "COGL_MATERIAL_WRAP_MODE_AUTOMATIC", "automatic" },
+        { 0, NULL, NULL }
+      };
+      GType g_enum_type_id;
+
+      g_enum_type_id =
+        g_enum_register_static (g_intern_static_string ("CoglMaterialWrapMode"), values);
+
+      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
+    }
+
+  return g_enum_type_id__volatile;
+}
+GType
 cogl_material_alpha_func_get_type (void)
 {
   static volatile gsize g_enum_type_id__volatile = 0;
@@ -196,6 +224,60 @@ cogl_material_layer_type_get_type (void)
 
   return g_enum_type_id__volatile;
 }
+GType
+cogl_depth_test_function_get_type (void)
+{
+  static volatile gsize g_enum_type_id__volatile = 0;
+
+  if (g_once_init_enter (&g_enum_type_id__volatile))
+    {
+      static const GEnumValue values[] = {
+        { COGL_DEPTH_TEST_FUNCTION_NEVER, "COGL_DEPTH_TEST_FUNCTION_NEVER", "never" },
+        { COGL_DEPTH_TEST_FUNCTION_LESS, "COGL_DEPTH_TEST_FUNCTION_LESS", "less" },
+        { COGL_DEPTH_TEST_FUNCTION_EQUAL, "COGL_DEPTH_TEST_FUNCTION_EQUAL", "equal" },
+        { COGL_DEPTH_TEST_FUNCTION_LEQUAL, "COGL_DEPTH_TEST_FUNCTION_LEQUAL", "lequal" },
+        { COGL_DEPTH_TEST_FUNCTION_GREATER, "COGL_DEPTH_TEST_FUNCTION_GREATER", "greater" },
+        { COGL_DEPTH_TEST_FUNCTION_NOTEQUAL, "COGL_DEPTH_TEST_FUNCTION_NOTEQUAL", "notequal" },
+        { COGL_DEPTH_TEST_FUNCTION_GEQUAL, "COGL_DEPTH_TEST_FUNCTION_GEQUAL", "gequal" },
+        { COGL_DEPTH_TEST_FUNCTION_ALWAYS, "COGL_DEPTH_TEST_FUNCTION_ALWAYS", "always" },
+        { 0, NULL, NULL }
+      };
+      GType g_enum_type_id;
+
+      g_enum_type_id =
+        g_enum_register_static (g_intern_static_string ("CoglDepthTestFunction"), values);
+
+      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
+    }
+
+  return g_enum_type_id__volatile;
+}
+
+/* enumerations from "./cogl-path.h" */
+#include "./cogl-path.h"
+
+GType
+cogl_path_fill_rule_get_type (void)
+{
+  static volatile gsize g_enum_type_id__volatile = 0;
+
+  if (g_once_init_enter (&g_enum_type_id__volatile))
+    {
+      static const GEnumValue values[] = {
+        { COGL_PATH_FILL_RULE_NON_ZERO, "COGL_PATH_FILL_RULE_NON_ZERO", "non-zero" },
+        { COGL_PATH_FILL_RULE_EVEN_ODD, "COGL_PATH_FILL_RULE_EVEN_ODD", "even-odd" },
+        { 0, NULL, NULL }
+      };
+      GType g_enum_type_id;
+
+      g_enum_type_id =
+        g_enum_register_static (g_intern_static_string ("CoglPathFillRule"), values);
+
+      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
+    }
+
+  return g_enum_type_id__volatile;
+}
 
 /* enumerations from "./cogl-shader.h" */
 #include "./cogl-shader.h"
@@ -286,6 +368,7 @@ cogl_feature_flags_get_type (void)
         { COGL_FEATURE_VBOS, "COGL_FEATURE_VBOS", "vbos" },
         { COGL_FEATURE_PBOS, "COGL_FEATURE_PBOS", "pbos" },
         { COGL_FEATURE_UNSIGNED_INT_INDICES, "COGL_FEATURE_UNSIGNED_INT_INDICES", "unsigned-int-indices" },
+        { COGL_FEATURE_DEPTH_RANGE, "COGL_FEATURE_DEPTH_RANGE", "depth-range" },
         { 0, NULL, NULL }
       };
       GType g_enum_type_id;
@@ -391,6 +474,27 @@ cogl_blend_string_error_get_type (void)
 
   return g_enum_type_id__volatile;
 }
+GType
+cogl_error_get_type (void)
+{
+  static volatile gsize g_enum_type_id__volatile = 0;
+
+  if (g_once_init_enter (&g_enum_type_id__volatile))
+    {
+      static const GEnumValue values[] = {
+        { COGL_ERROR_MISSING_FEATURE, "COGL_ERROR_MISSING_FEATURE", "missing-feature" },
+        { 0, NULL, NULL }
+      };
+      GType g_enum_type_id;
+
+      g_enum_type_id =
+        g_enum_register_static (g_intern_static_string ("CoglError"), values);
+
+      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
+    }
+
+  return g_enum_type_id__volatile;
+}
 
 /* enumerations from "./cogl-vertex-buffer.h" */
 #include "./cogl-vertex-buffer.h"
@@ -541,5 +645,33 @@ cogl_driver_error_get_type (void)
   return g_enum_type_id__volatile;
 }
 
+/* enumerations from "./winsys/cogl-texture-pixmap-x11.h" */
+#include "./winsys/cogl-texture-pixmap-x11.h"
+
+GType
+cogl_texture_pixmap_x11_report_level_get_type (void)
+{
+  static volatile gsize g_enum_type_id__volatile = 0;
+
+  if (g_once_init_enter (&g_enum_type_id__volatile))
+    {
+      static const GEnumValue values[] = {
+        { COGL_TEXTURE_PIXMAP_X11_DAMAGE_RAW_RECTANGLES, "COGL_TEXTURE_PIXMAP_X11_DAMAGE_RAW_RECTANGLES", "raw-rectangles" },
+        { COGL_TEXTURE_PIXMAP_X11_DAMAGE_DELTA_RECTANGLES, "COGL_TEXTURE_PIXMAP_X11_DAMAGE_DELTA_RECTANGLES", "delta-rectangles" },
+        { COGL_TEXTURE_PIXMAP_X11_DAMAGE_BOUNDING_BOX, "COGL_TEXTURE_PIXMAP_X11_DAMAGE_BOUNDING_BOX", "bounding-box" },
+        { COGL_TEXTURE_PIXMAP_X11_DAMAGE_NON_EMPTY, "COGL_TEXTURE_PIXMAP_X11_DAMAGE_NON_EMPTY", "non-empty" },
+        { 0, NULL, NULL }
+      };
+      GType g_enum_type_id;
+
+      g_enum_type_id =
+        g_enum_register_static (g_intern_static_string ("CoglTexturePixmapX11ReportLevel"), values);
+
+      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
+    }
+
+  return g_enum_type_id__volatile;
+}
+
 /* Generated data ends here */
 
