@@ -37,6 +37,7 @@
 #include "cogl-bitmap-private.h"
 #include "cogl-texture-private.h"
 #include "cogl-material.h"
+#include "cogl-material-private.h"
 #include "cogl-context.h"
 #include "cogl-handle.h"
 #include "cogl-primitives.h"
@@ -58,7 +59,7 @@ _cogl_texture_driver_gen (GLenum   gl_target,
 
   for (i = 0; i < n; i++)
     {
-      GE (glBindTexture (gl_target, textures[i]));
+      _cogl_bind_gl_texture_transient (gl_target, textures[i], FALSE);
 
       switch (gl_target)
         {
@@ -91,6 +92,7 @@ _cogl_texture_driver_prep_gl_for_pixels_download (int pixels_rowstride,
 void
 _cogl_texture_driver_upload_subregion_to_gl (GLenum       gl_target,
                                              GLuint       gl_handle,
+                                             gboolean     is_foreign,
                                              int          src_x,
                                              int          src_y,
                                              int          dst_x,
@@ -131,7 +133,7 @@ _cogl_texture_driver_upload_subregion_to_gl (GLenum       gl_target,
                                slice_bmp.width,
                                slice_bmp.height);
 
-  GE( glBindTexture (gl_target, gl_handle) );
+  _cogl_bind_gl_texture_transient (gl_target, gl_handle, is_foreign);
 
   GE( glTexSubImage2D (gl_target, 0,
                        dst_x, dst_y,
@@ -147,6 +149,7 @@ _cogl_texture_driver_upload_subregion_to_gl (GLenum       gl_target,
 void
 _cogl_texture_driver_upload_to_gl (GLenum       gl_target,
                                    GLuint       gl_handle,
+                                   gboolean     is_foreign,
                                    CoglBitmap  *source_bmp,
                                    GLint        internal_gl_format,
                                    GLuint       source_gl_format,
@@ -175,7 +178,7 @@ _cogl_texture_driver_upload_to_gl (GLenum       gl_target,
   _cogl_texture_driver_prep_gl_for_pixels_upload (bmp.rowstride,
                                                   bpp);
 
-  GE( glBindTexture (gl_target, gl_handle) );
+  _cogl_bind_gl_texture_transient (gl_target, gl_handle, is_foreign);
 
   GE( glTexImage2D (gl_target, 0,
                     internal_gl_format,
@@ -322,7 +325,7 @@ _cogl_texture_driver_allows_foreign_gl_target (GLenum gl_target)
 void
 _cogl_texture_driver_gl_generate_mipmaps (GLenum gl_target)
 {
-  GE( cogl_wrap_glGenerateMipmap (gl_target) );
+  GE( _cogl_wrap_glGenerateMipmap (gl_target) );
 }
 
 CoglPixelFormat
