@@ -30,7 +30,6 @@
 #endif
 
 #include "cogl.h"
-#include "cogl-debug.h"
 #include "cogl-internal.h"
 #include "cogl-util.h"
 #include "cogl-texture-pixmap-x11.h"
@@ -43,7 +42,6 @@
 #include "cogl-context.h"
 #include "cogl-handle.h"
 #include "cogl-xlib.h"
-#include "cogl-material-opengl-private.h"
 
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
@@ -1120,14 +1118,18 @@ _cogl_texture_pixmap_x11_set_region (CoglTexture     *tex,
                                      int              dst_y,
                                      unsigned int     dst_width,
                                      unsigned int     dst_height,
-                                     CoglBitmap      *bmp)
+                                     int              width,
+                                     int              height,
+                                     CoglPixelFormat  format,
+                                     unsigned int     rowstride,
+                                     const guint8    *data)
 {
   /* This doesn't make much sense for texture from pixmap so it's not
      supported */
   return FALSE;
 }
 
-static gboolean
+static int
 _cogl_texture_pixmap_x11_get_data (CoglTexture     *tex,
                                    CoglPixelFormat  format,
                                    unsigned int     rowstride,
@@ -1288,7 +1290,7 @@ static void
 _cogl_texture_pixmap_x11_set_wrap_mode_parameters (CoglTexture *tex,
                                                    GLenum       wrap_mode_s,
                                                    GLenum       wrap_mode_t,
-                                                   GLenum       wrap_mode_p)
+                                                   GLenum       wrap_mode_r)
 {
   CoglTexturePixmapX11 *tex_pixmap = COGL_TEXTURE_PIXMAP_X11 (tex);
   CoglHandle child_tex;
@@ -1299,7 +1301,7 @@ _cogl_texture_pixmap_x11_set_wrap_mode_parameters (CoglTexture *tex,
   _cogl_texture_set_wrap_mode_parameters (child_tex,
                                           wrap_mode_s,
                                           wrap_mode_t,
-                                          wrap_mode_p);
+                                          wrap_mode_r);
 }
 
 static CoglPixelFormat
