@@ -108,13 +108,10 @@ xsettings_filter (XEvent       *xevent,
 {
   ClutterBackendX11 *backend_x11 = data;
 
-  _clutter_xsettings_client_process_event (backend_x11->xsettings, xevent);
-
-  /* we always want the rest of the stack to get XSettings events, even
-   * if Clutter already handled them
-   */
-
-  return CLUTTER_X11_FILTER_CONTINUE;
+  if (_clutter_xsettings_client_process_event (backend_x11->xsettings, xevent))
+    return CLUTTER_X11_FILTER_REMOVE;
+  else
+    return CLUTTER_X11_FILTER_CONTINUE;
 }
 
 static Bool
@@ -319,12 +316,6 @@ clutter_backend_x11_post_parse (ClutterBackend  *backend,
                       "backend", backend_x11,
                       NULL);
 
-      /* register keymap */
-      backend_x11->keymap =
-        g_object_new (CLUTTER_TYPE_KEYMAP_X11,
-                      "backend", backend_x11,
-                      NULL);
-
       /* create XSETTINGS client */
       backend_x11->xsettings =
         _clutter_xsettings_client_new (backend_x11->xdpy,
@@ -481,29 +472,6 @@ clutter_backend_x11_get_features (ClutterBackend *backend)
   return CLUTTER_FEATURE_STAGE_USER_RESIZE | CLUTTER_FEATURE_STAGE_CURSOR;
 }
 
-static void
-clutter_backend_x11_copy_event_data (ClutterBackend *backend,
-                                     ClutterEvent   *src,
-                                     ClutterEvent   *dest)
-{
-  gpointer event_x11;
-
-  event_x11 = _clutter_event_get_platform_data (src);
-  if (event_x11 != NULL)
-    _clutter_event_set_platform_data (dest, _clutter_event_x11_copy (event_x11));
-}
-
-static void
-clutter_backend_x11_free_event_data (ClutterBackend *backend,
-                                     ClutterEvent   *event)
-{
-  gpointer event_x11;
-
-  event_x11 = _clutter_event_get_platform_data (event);
-  if (event_x11 != NULL)
-    _clutter_event_x11_free (event_x11);
-}
-
 gboolean
 clutter_backend_x11_handle_event (ClutterBackendX11 *backend_x11,
                                   XEvent *xevent)
@@ -545,8 +513,6 @@ clutter_backend_x11_class_init (ClutterBackendX11Class *klass)
   backend_class->add_options = clutter_backend_x11_add_options;
   backend_class->get_features = clutter_backend_x11_get_features;
   backend_class->get_device_manager = clutter_backend_x11_get_device_manager;
-  backend_class->copy_event_data = clutter_backend_x11_copy_event_data;
-  backend_class->free_event_data = clutter_backend_x11_free_event_data;
 
   backendx11_class->handle_event = clutter_backend_x11_handle_event;
 }
@@ -673,27 +639,12 @@ clutter_x11_enable_xinput (void)
 }
 
 /**
- * clutter_x11_disable_event_retrieval:
+ * clutter_x11_disable_event_retrieval
  *
- * Disables the internal polling of X11 events in the main loop.
+ * Disables retrieval of X events in the main loop. Use to create event-less
+ * canvas or in conjunction with clutter_x11_handle_event.
  *
- * Libraries or applications calling this function will be responsible of
- * polling all X11 events.
- *
- * You also must call clutter_x11_handle_event() to let Clutter process
- * events and maintain its internal state.
- *
- * <warning>This function can only be called before calling
- * clutter_init().</warning>
- *
- * <note>Even with event handling disabled, Clutter will still select
- * all the events required to maintain its internal state on the stage
- * Window; compositors using Clutter and input regions to pass events
- * through to application windows should not rely on an empty input
- * region, and should instead clear it themselves explicitly using the
- * XFixes extension.</note>
- *
- * This function should not be normally used by applications.
+ * This function can only be called before calling clutter_init().
  *
  * Since: 0.8
  */
@@ -711,7 +662,7 @@ clutter_x11_disable_event_retrieval (void)
 }
 
 /**
- * clutter_x11_has_event_retrieval:
+ * clutter_x11_has_event_retrieval
  *
  * Queries the X11 backend to check if event collection has been disabled.
  *
