@@ -144,7 +144,9 @@ main (int argc, char **argv)
   TEST_CONFORM_SIMPLE ("/opacity", test_rectangle_opacity);
   TEST_CONFORM_SIMPLE ("/opacity", test_paint_opacity);
 
+  TEST_CONFORM_SIMPLE ("/texture", test_texture_pick_with_alpha);
   TEST_CONFORM_SIMPLE ("/texture", test_texture_fbo);
+  TEST_CONFORM_SIMPLE ("/texture/cairo", test_clutter_cairo_texture);
 
   TEST_CONFORM_SIMPLE ("/path", test_path);
 
@@ -183,21 +185,29 @@ main (int argc, char **argv)
   TEST_CONFORM_SIMPLE ("/script", test_animator_base);
   TEST_CONFORM_SIMPLE ("/script", test_animator_properties);
   TEST_CONFORM_SIMPLE ("/script", test_animator_multi_properties);
+  TEST_CONFORM_SIMPLE ("/script", test_state_base);
+  TEST_CONFORM_SIMPLE ("/script", test_script_layout_property);
 
   TEST_CONFORM_SIMPLE ("/behaviours", test_behaviours);
 
+  TEST_CONFORM_SIMPLE ("/cogl", test_cogl_object);
   TEST_CONFORM_SIMPLE ("/cogl", test_cogl_fixed);
   TEST_CONFORM_SIMPLE ("/cogl", test_cogl_backface_culling);
   TEST_CONFORM_SIMPLE ("/cogl", test_cogl_materials);
   TEST_CONFORM_SIMPLE ("/cogl", test_cogl_blend_strings);
   TEST_CONFORM_SIMPLE ("/cogl", test_cogl_premult);
   TEST_CONFORM_SIMPLE ("/cogl", test_cogl_readpixels);
+  TEST_CONFORM_SIMPLE ("/cogl", test_cogl_path);
+  TEST_CONFORM_SIMPLE ("/cogl", test_cogl_depth_test);
 
   TEST_CONFORM_SIMPLE ("/cogl/texture", test_cogl_npot_texture);
   TEST_CONFORM_SIMPLE ("/cogl/texture", test_cogl_multitexture);
   TEST_CONFORM_SIMPLE ("/cogl/texture", test_cogl_texture_mipmaps);
   TEST_CONFORM_SIMPLE ("/cogl/texture", test_cogl_sub_texture);
   TEST_CONFORM_SIMPLE ("/cogl/texture", test_cogl_pixel_buffer);
+  TEST_CONFORM_SIMPLE ("/cogl/texture", test_cogl_texture_rectangle);
+  TEST_CONFORM_SIMPLE ("/cogl/texture", test_cogl_wrap_modes);
+  TEST_CONFORM_SIMPLE ("/cogl/texture", test_cogl_texture_pixmap_x11);
 
   TEST_CONFORM_SIMPLE ("/cogl/vertex-buffer", test_cogl_vertex_buffer_contiguous);
   TEST_CONFORM_SIMPLE ("/cogl/vertex-buffer", test_cogl_vertex_buffer_interleved);
